import * as tsp from 'typescript/lib/protocol';
import { KeybindingRegistry, KeybindingContribution, StorageService, LabelProvider, FrontendApplicationContribution, StatusBar } from '@devpodio/core/lib/browser';
import { QuickPickService } from '@devpodio/core/lib/common/quick-pick-service';
import { FileSystemWatcher, FileMoveEvent } from '@devpodio/filesystem/lib/browser';
import { EditorManager, EditorWidget, TextEditor } from '@devpodio/editor/lib/browser';
import { CommandContribution, CommandRegistry, Command, MenuModelRegistry, MenuContribution, DisposableCollection } from '@devpodio/core/lib/common';
import { TypeScriptClientContribution } from './typescript-client-contribution';
export declare namespace TypeScriptCommands {
    const applyCompletionCodeAction: Command;
    const organizeImports: Command;
    const openServerLog: Command;
    const selectVersion: Command;
}
export declare class TypeScriptFrontendContribution implements FrontendApplicationContribution, CommandContribution, MenuContribution, KeybindingContribution {
    protected readonly statusBar: StatusBar;
    protected readonly editorManager: EditorManager;
    protected readonly quickPickService: QuickPickService;
    protected readonly clientContribution: TypeScriptClientContribution;
    protected readonly fileSystemWatcher: FileSystemWatcher;
    protected readonly labelProvider: LabelProvider;
    protected readonly storage: StorageService;
    protected init(): void;
    onStart(): void;
    onStop(): void;
    registerCommands(commands: CommandRegistry): void;
    registerMenus(menus: MenuModelRegistry): void;
    registerKeybindings(keybindings: KeybindingRegistry): void;
    openServerLog(): void;
    organizeImports(): void;
    readonly currentEditor: EditorWidget | undefined;
    protected pickCodeAction(codeActions: tsp.CodeAction[]): Promise<tsp.CodeAction | undefined>;
    protected applyCodeAction(codeAction: tsp.CodeAction): Promise<any>;
    protected renameFile({ sourceUri, targetUri }: FileMoveEvent): Promise<void>;
    protected selectVersion(): Promise<void>;
    protected storageKey: string;
    protected restore(): Promise<void>;
    protected store(): Promise<void>;
    protected readonly toDisposeOnCurrentEditorChanged: DisposableCollection;
    protected updateStatusBar(): void;
    protected updateVersionStatus(editor: TextEditor | undefined): void;
}
